#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-lua
version:              1.1.1.1
visibility:           public
id:                   tasty-lua-1.1.1.1-24h9bgurwNx2jvqqRo8M1k
key:                  tasty-lua-1.1.1.1-24h9bgurwNx2jvqqRo8M1k
license:              MIT
copyright:            © 2019-2025 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  9c1ecba3e7064031296b3f838a8dc6f5
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.1.1.1-24h9bgurwNx2jvqqRo8M1k
depends:
    QuickCheck-2.15.0.1-KbEu55Yn4v1JAMl6aurZE0 base-4.18.2.1
    bytestring-0.11.5.3 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    hslua-core-2.3.2-LReI2UbiKlPKhkX09mt71p
    hslua-marshalling-2.3.1-A5aoNaanlpK2FggCiFCUn4
    lua-arbitrary-1.0.1.2-L1mONRHjaQR448Moq9D5Lm
    tasty-1.5.2-Ecucfh1EfNvF5aNYdx3wDU

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

